# Pythonic scripting library for cleaning data in `Crunch <http://crunch.io/>`__

To learn more, including how to install the library, see the
[Overview](https://github.com/Crunch-io/scrunch/wiki/Overview) wiki
page.

Once you have it installed, to get started using `scrunch` to work with data in
Crunch, see the [User Guide](https://github.com/Crunch-io/scrunch/wiki/User-Reference).
